#
# spec file for package lxqt-openssh-askpass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-openssh-askpass
Version:        2.1.0
Release:        1.2
Summary:        GUI to query passwords on behalf of SSH agents
License:        LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            https://github.com/lxqt/lxqt-openssh-askpass
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(lxqt2-build-tools)
BuildRequires:  pkgconfig(lxqt) >= 2.1.0
Recommends:     %{name}-lang = %{version}-%{release}

%description
lxqt-openssh-askpass is a GUI to query credentials on behalf of other
programs. As indicated by its name it's primarily targeted at ssh-agent,
the SSH agent of OpenSSH, but it works with other applications like e. g.
EncFS as well.

%lang_package

%prep
%autosetup

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}

%find_lang %{name} --with-qt

%files
%doc AUTHORS CHANGELOG README.md
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}
%license LICENSE

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/%{name}

%changelog
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes
  * Weblate commits (#99)
  * Pre-release changes
  * Fixed input focus with Qt6
  * Pre-release changes
  * Weblate commits (#94)
* Sat May 18 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.1:
  * Fixed the Focus of the input entry with Qt6.
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6.
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Updated translations and bumped the version.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Bumped the version to that of the latest LXQt
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Bumped the version to 1.2.0
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Updated translations
* Fri Nov  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version to 5.15.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Updated translations
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Bumped version to 0.16.0
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-openssh-askpass.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Fixed the patch version and removed (duplicated) string casts definitions.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Installed former missed man pages
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * CMake: Prevent in-source builds
  * fix razor-qt -> lxqt and http -> https
  * Fixed mentions of LXDE
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * Drops Qt5Core_VERSION_STRING
  * set Qt::AA_UseHighDpiPixmaps to true
  * Added QCommandLineParser and basic cli interface to lxqt-openssh-askpass
  * Added default CMAKE_BUILD_TYPE and LXQT_ASKPASS_PATCH_VERSION
  * Bump year
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Make CMakeLists.txt more uniform.
  * Remove cpack (#21)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Rework README.md
  * build: Use external translations
  * ts-files removal (#19)
  * Fix typo in German translation (#18)
  * Bump year Fix licenses, lxqt-openssh-askpass is LGPL only
  * Italian translation update
  * Fix target language in translation file template
  * Remove ru_RU translation file
  * new: lxqt-openssh-askpass_hu.ts
- Add keyring
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to enable building for Fedora
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del: lxqt-openssh-askpass-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-openssh-askpass-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for stable release
  Add:  lxqt-openssh-askpass-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-openssh-askpass.spec
  Add: lxqt-openssh-askpass.changes
